"use strict";
var chai = require("chai");
var chaiAsPromised = require("chai-as-promised");
var SubscriptionManager_1 = require("../SubscriptionManager");
var rokot_log_1 = require("rokot-log");
var amqp_pubsub_1 = require("../amqp-pubsub");
var graphql_1 = require("graphql");
var logger = rokot_log_1.ConsoleLogger.create("integration-test", { level: "trace" });
chai.use(chaiAsPromised);
var expect = chai.expect;
var assert = chai.assert;
var QueryRootType = new graphql_1.GraphQLObjectType({
    name: 'QueryRoot',
    fields: {
        test: {
            type: graphql_1.GraphQLString,
            args: {
                who: {
                    type: graphql_1.GraphQLString
                }
            },
            resolve: function (root, args) { return 'Hello ' + (args['who'] || 'World'); }
        },
        thrower: {
            type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLString),
            resolve: function () { throw new Error('Throws!'); }
        },
        context: {
            type: graphql_1.GraphQLString,
            resolve: function (obj, args, context) { return context; }
        }
    }
});
var TestSchema = new graphql_1.GraphQLSchema({
    query: QueryRootType,
    mutation: new graphql_1.GraphQLObjectType({
        name: 'MutationRoot',
        fields: {
            writeTest: {
                type: QueryRootType,
                resolve: function () { return ({}); }
            }
        }
    })
});
var UploadedFileType = new graphql_1.GraphQLObjectType({
    name: 'UploadedFile',
    fields: {
        originalname: { type: graphql_1.GraphQLString },
        mimetype: { type: graphql_1.GraphQLString }
    }
});
var TestMutationSchema = new graphql_1.GraphQLSchema({
    query: new graphql_1.GraphQLObjectType({
        name: 'QueryRoot',
        fields: {
            test: { type: graphql_1.GraphQLString }
        }
    }),
    mutation: new graphql_1.GraphQLObjectType({
        name: 'MutationRoot',
        fields: {
            uploadFile: {
                type: UploadedFileType,
                resolve: function (rootValue) {
                    return "test";
                }
            }
        }
    })
});
var QueryType = new graphql_1.GraphQLObjectType({
    name: 'QueryType',
    fields: {
        testString: {
            type: graphql_1.GraphQLString,
            resolve: function () {
                return 'it works';
            }
        },
        testContext: {
            type: graphql_1.GraphQLString,
            resolve: function (_, args, context) {
                if (context.otherField) {
                    return 'unexpected';
                }
                context.otherField = true;
                return context.testField;
            }
        },
        testRootValue: {
            type: graphql_1.GraphQLString,
            resolve: function (rootValue) {
                return rootValue;
            }
        },
        testArgument: {
            type: graphql_1.GraphQLString,
            args: { echo: { type: graphql_1.GraphQLString } },
            resolve: function (root, _a) {
                var echo = _a.echo;
                return "hello " + echo;
            }
        },
        testError: {
            type: graphql_1.GraphQLString,
            resolve: function () {
                throw new Error('Secret error message');
            }
        }
    }
});
var MutationType = new graphql_1.GraphQLObjectType({
    name: 'MutationType',
    fields: {
        testMutation: {
            type: graphql_1.GraphQLString,
            args: { echo: { type: graphql_1.GraphQLString } },
            resolve: function (root, _a) {
                var echo = _a.echo;
                return "not really a mutation, but who cares: " + echo;
            }
        }
    }
});
var SubscriptionType = new graphql_1.GraphQLObjectType({
    name: 'Subscription',
    fields: {
        testSubscription: {
            type: graphql_1.GraphQLString,
            resolve: function (root) {
                return root;
            }
        }
    }
});
exports.Schema = new graphql_1.GraphQLSchema({
    query: QueryType,
    mutation: MutationType,
    subscription: SubscriptionType
});
describe('SubscriptionManager to test Mutation', function () {
    this.timeout(30000);
    var subManager = new SubscriptionManager_1.AMQPSubscriptionManager({
        schema: exports.Schema,
        setupFunctions: {},
        pubsub: new amqp_pubsub_1.AmqpPubSub({ logger: logger })
    });
    it('rejects subscriptions with more than one root field', function () {
        var query = 'subscription X{ a: testSubscription, b: testSubscription }';
        var callback = function () { return null; };
        return expect(subManager.subscribe({ query: query, operationName: 'X', callback: callback }))
            .to.eventually.be.rejectedWith('Subscription query has validation errors');
    });
});
//# sourceMappingURL=subscribe-tests.js.map